# Table of Contents

- [zscaler-integration-for-saas-discovery](<./zscaler-integration-for-saas-discovery.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Zscaler Integration for SaaS Discovery](<./Zscaler-Integration-for-SaaS-Discovery.md>)
  - [Introduction](<./Zscaler-Integration-for-SaaS-Discovery/Introduction.md>)
  - [Implementation Details](<./Zscaler-Integration-for-SaaS-Discovery/Implementation-Details.md>)
  - [Discovery Capabilities](<./Zscaler-Integration-for-SaaS-Discovery/Discovery-Capabilities.md>)
  - [Setting up Zscaler Integration](<./Zscaler-Integration-for-SaaS-Discovery/Setting-up-Zscaler-Integration.md>)
  - [Create a New API Role](<./Zscaler-Integration-for-SaaS-Discovery/Create-a-New-API-Role.md>)
  - [Create a New User for the Integration](<./Zscaler-Integration-for-SaaS-Discovery/Create-a-New-User-for-the-Integration.md>)
  - [Create an API Token in Zscaler](<./Zscaler-Integration-for-SaaS-Discovery/Create-an-API-Token-in-Zscaler.md>)
  - [Enter the Necessary Credentials in SAP LeanIX](<./Zscaler-Integration-for-SaaS-Discovery/Enter-the-Necessary-Credentials-in-SAP-LeanIX.md>)
  - [Was this page helpful?](<./Zscaler-Integration-for-SaaS-Discovery/Was-this-page-helpful.md>)
